import React, { useState, useEffect, useCallback } from "react";
import {
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Stack,
    Grid,
    TextField,
    Box,
    Button,
    Paper,
    styled,
    RadioGroup,
    Radio,
    FormControlLabel,
} from '@mui/material';
import DialogCloseButton from "../components/DialogCloseButton";
import ConfirmButton from "../components/ConfirmButton";
import { useTranslate, useNotify, useRefresh } from 'react-admin';
import request from '@/utils/request';
import { DataGrid, useGridApiRef } from '@mui/x-data-grid';
import SaveIcon from '@mui/icons-material/Save';
import TreeSelectInput from "@/page/components/TreeSelectInput";
import { throttle } from 'lodash';

const AsnSelModal = (props) => {
    const { open, setOpen } = props;

    const translate = useTranslate();
    const notify = useNotify();
    const refresh = useRefresh();

    const handleClose = (event, reason) => {
        if (reason !== "backdropClick") {
            setOpen(false);
        }
    };

    const [formData, setFormData] = useState({
        asnCode: ''
    });

    const [tableData, setTableData] = useState([]);
    const [selectedRows, setSelectedRows] = useState([]);

    const handleChange = (e) => {
        const { name, value } = e.target;
        setFormData((prevData) => ({
            ...prevData,
            [name]: value
        }));
    };

    const reset = () => {
        setFormData({
            asnCode: ''
        })
    }

    const handleSubmit = async () => {
        const { data: { code, data, msg } } = await request.post(`/qlyInspect/selected`, { ids: selectedRows });

        if (code === 200) {
            notify(msg);
            refresh()
        } else {
            notify(msg);
        }
        setOpen(false);
        reset();
    };

    const getData = async () => {
        const res = await request.post(`/qlyInspect/asn/list`, { asnCode: formData.asnCode });
        if (res?.data?.code === 200) {
            setTableData(res.data.data);
        } else {
            notify(res.data.msg);
        }
    };

    useEffect(() => {
        getData();
    }, [open]);

    const handleSearch = () => {
        getData()
    };

    return (
        <Dialog
            open={open}
            onClose={handleClose}
            aria-labelledby="form-dialog-title"
            fullWidth
            disableRestoreFocus
            maxWidth="lg"
        >
            <DialogTitle id="form-dialog-title" sx={{
                position: 'sticky',
                top: 0,
                backgroundColor: 'background.paper',
                zIndex: 1000
            }}>
                选择asn单
                <Box sx={{ position: 'absolute', top: 8, right: 8, zIndex: 1001 }}>
                    <DialogCloseButton onClose={handleClose} />
                </Box>
            </DialogTitle>
            <DialogContent sx={{ mt: 2 }}>
                <Box component="form" onSubmit={handleSubmit} sx={{ display: 'flex', flexDirection: 'column', gap: 3 }}>
                    <Grid container spacing={2}>
                        <Grid item md={4}>
                            <TextField
                                label={translate('table.field.asnOrder.code')}
                                name="asnCode"
                                value={formData.asnCode}
                                onChange={handleChange}
                                size="small"
                            />
                        </Grid>
                    </Grid>
                </Box>
                <Box sx={{ mt: 2 }}>
                    <Stack direction="row" spacing={2}>
                        <Button variant="contained" onClick={handleSearch}>搜索</Button>
                    </Stack>
                </Box>
                <Box sx={{ mt: 2, height: 400, width: '100%' }}>
                    <AsnSelModalTable
                        tableData={tableData}
                        setTableData={setTableData}
                        selectedRows={selectedRows}
                        setSelectedRows={setSelectedRows}
                    />
                </Box>
            </DialogContent>
            <DialogActions sx={{ position: 'sticky', bottom: 0, backgroundColor: 'background.paper', zIndex: 1000 }}>
                <Box sx={{ width: '100%', display: 'flex', justifyContent: 'space-between' }}>
                    <Button onClick={handleSubmit} variant="contained" startIcon={<SaveIcon />}>
                        {translate('toolbar.confirm')}
                    </Button>
                </Box>
            </DialogActions>
        </Dialog>
    );
};

export default AsnSelModal;

const AsnSelModalTable = ({ tableData, setTableData, selectedRows, setSelectedRows }) => {
    const translate = useTranslate();
    const notify = useNotify();
    const apiRef = useGridApiRef();

    const handleSelectionChange = (ids) => {
        setSelectedRows(ids)

    };


    const [columns, setColumns] = useState([
        // { field: 'id', headerName: 'ID', width: 100 },
        { field: 'code', headerName: translate('table.field.asnOrder.code'), width: 200 },
        { field: 'type$', headerName: translate('table.field.asnOrder.type') },
        { field: 'wkType$', headerName: translate('table.field.asnOrder.wkType') },
        { field: 'anfme', headerName: translate('table.field.asnOrder.anfme') },
        { field: 'qty', headerName: translate('table.field.asnOrder.qty') },
        { field: 'logisNo', headerName: translate('table.field.asnOrder.logisNo') },
    ])


    return (
        <div style={{ height: 400, width: '100%' }}>
            <DataGrid
                size="small"
                rows={tableData}
                columns={columns}
                checkboxSelection
                onRowSelectionModelChange={handleSelectionChange}
                selectionModel={selectedRows}
                apiRef={apiRef}
                disableColumnMenu={true}
                disableColumnSorting
                disableMultipleColumnsSorting
            />
        </div>
    );
};